#
# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
#
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Utilies to run a separated DBus session."""

import os
import signal
import subprocess

from distutils.spawn import find_executable

SRCDIR = os.environ.get('SRCDIR', os.getcwd())


class DBusLaunchError(Exception):
    """Error while launching dbus-daemon."""


class NotFoundError(Exception):
    """Not found error."""


class DBusRunner(object):
    """A DBus runner."""

    # pylint: disable=C0103

    def __init__(self):
        self.dbus_address = None
        self.dbus_pid = None
        self.running = False

    def startDBus(self):
        """Start our own session bus daemon for testing."""
        dbus = find_executable("dbus-daemon")
        if not dbus:
            raise NotFoundError("dbus-daemon was not found.")

        config_file = os.path.join(os.path.abspath(SRCDIR),
                                   "contrib", "testing",
                                   "dbus-session.conf")
        dbus_args = ["--fork",
                     "--config-file=" + config_file,
                     "--print-address=1",
                     "--print-pid=2"]
        p = subprocess.Popen([dbus] + dbus_args,
                             bufsize=4096, stdout=subprocess.PIPE,
                             stderr=subprocess.PIPE)

        self.dbus_address = "".join(p.stdout.readlines()).strip()
        self.dbus_pid = int("".join(p.stderr.readlines()).strip())

        if self.dbus_address != "":
            os.environ["DBUS_SESSION_BUS_ADDRESS"] = self.dbus_address
        else:
            os.kill(self.dbus_pid, signal.SIGKILL)
            raise DBusLaunchError("There was a problem launching dbus-daemon.")
        self.running = True

    def stopDBus(self):
        """Stop our DBus session bus daemon."""
        del os.environ["DBUS_SESSION_BUS_ADDRESS"]
        os.kill(self.dbus_pid, signal.SIGKILL)
        self.running = False
